<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="uk_UA">
<context>
    <name>AudioCaptureSession</name>
    <message>
        <source>RAW file format</source>
        <translation>Файл формату RAW</translation>
    </message>
    <message>
        <source>WAV file format</source>
        <translation>Файл формату WAV</translation>
    </message>
</context>
<context>
    <name>AudioEncoderControl</name>
    <message>
        <source>PCM audio data</source>
        <translation>Аудіо дані PCM</translation>
    </message>
</context>
<context>
    <name>CameraBinAudioEncoder</name>
    <message>
        <source>Raw PCM audio</source>
        <translation>Сире аудіо PCM</translation>
    </message>
</context>
<context>
    <name>CameraBinImageEncoder</name>
    <message>
        <source>JPEG image</source>
        <translation>Зображення JPEG</translation>
    </message>
</context>
<context>
    <name>CameraBinRecorder</name>
    <message>
        <source>Service has not been started</source>
        <translation>Сервіс не було запущено</translation>
    </message>
    <message>
        <source>Not compatible codecs and container format.</source>
        <translation>Несумісні кодеки та формат контейнера.</translation>
    </message>
</context>
<context>
    <name>QCamera</name>
    <message>
        <source>The camera service is missing</source>
        <translation>Відсутній сервіс камери</translation>
    </message>
</context>
<context>
    <name>QCameraImageCapture</name>
    <message>
        <source>Device does not support images capture.</source>
        <translation>Пристрій не підтримує захоплення зображень.</translation>
    </message>
</context>
<context>
    <name>QCameraPrivate</name>
    <message>
        <source>The camera service is missing</source>
        <translation>Відсутній сервіс камери</translation>
    </message>
</context>
<context>
    <name>QDeclarativeDocumentGallery</name>
    <message>
        <source>DocumentGallery is a namespace class</source>
        <translation>DocumentGallery є класом простору імен</translation>
    </message>
</context>
<context>
    <name>QDeclarativeLandmarkFilterBase</name>
    <message>
        <source>LandmarkFilterBase is an abstract class</source>
        <translation>LandmarkFilterBase - абстрактний клас</translation>
    </message>
</context>
<context>
    <name>QDeclarativeMessageFilterBase</name>
    <message>
        <source>MessageFilterBase is an abstract class</source>
        <translation>MessageFilterBase - абстрактний клас</translation>
    </message>
</context>
<context>
    <name>QGstreamerAudioEncode</name>
    <message>
        <source>Raw PCM audio</source>
        <translation>Сире аудіо PCM</translation>
    </message>
</context>
<context>
    <name>QGstreamerCaptureSession</name>
    <message>
        <source>Could not create an audio source element</source>
        <translation>Не вдалось створити елемент аудіо-джерела</translation>
    </message>
    <message>
        <source>Failed to build media capture pipeline.</source>
        <translation>Збій побудови конвеєру захоплення медіа.</translation>
    </message>
</context>
<context>
    <name>QGstreamerPlayerSession</name>
    <message>
        <source>Unable to play %1</source>
        <translation>Неможливо відтворити %1</translation>
    </message>
</context>
<context>
    <name>QGstreamerRecorderControl</name>
    <message>
        <source>Service has not been started</source>
        <translation>Сервіс має бути запущеним</translation>
    </message>
    <message>
        <source>Not compatible codecs and container format.</source>
        <translation>Несумісні кодеки та формат контейнера.</translation>
    </message>
</context>
<context>
    <name>QMediaPlayer</name>
    <message>
        <source>The QMediaPlayer object does not have a valid service</source>
        <translation>Об&apos;єкт QMediaPlayer не має дійсного сервісу</translation>
    </message>
</context>
<context>
    <name>QMediaPlaylist</name>
    <message>
        <source>Could not add items to read only playlist.</source>
        <translation>Не вдалось додати елементи в список програвання лише для читання.</translation>
    </message>
    <message>
        <source>Playlist format is not supported</source>
        <translation>Формат списку програвання не підтримується</translation>
    </message>
    <message>
        <source>The file could not be accessed.</source>
        <translation>Не вдалось отримати доступ до файлу.</translation>
    </message>
    <message>
        <source>Playlist format is not supported.</source>
        <translation>Формат списку програвання не підтримується.</translation>
    </message>
</context>
<context>
    <name>QMessage</name>
    <message>
        <source>Subject</source>
        <translation>Тема</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Дата</translation>
    </message>
    <message>
        <source>From</source>
        <translation>Від</translation>
    </message>
    <message>
        <source>To</source>
        <translation>Кому</translation>
    </message>
    <message>
        <source>On %1 you wrote:
&gt; </source>
        <translation>%1 ви писали:
&gt; </translation>
    </message>
    <message>
        <source>Forwarded Message</source>
        <translation>Переслане повідомлення</translation>
    </message>
</context>
<context>
    <name>QNetworkConfigurationManagerPrivate</name>
    <message>
        <source>Internet</source>
        <translation>Інтернет</translation>
    </message>
</context>
<context>
    <name>QNetworkSessionPrivate</name>
    <message>
        <source>Unknown session error.</source>
        <translation>Невідома помилка сесії.</translation>
    </message>
    <message>
        <source>The session was aborted by the user or system.</source>
        <translation>Сесія була перервана користувачем або системою.</translation>
    </message>
    <message>
        <source>The requested operation is not supported by the system.</source>
        <translation>Операція, що запитується, не підтримується системою.</translation>
    </message>
    <message>
        <source>The specified configuration cannot be used.</source>
        <translation>Вказана конфігурація не може бути використана.</translation>
    </message>
    <message>
        <source>Roaming was aborted or is not possible.</source>
        <translation>Переміщення було перерване або неможливе.</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Roaming error</source>
        <translation>Помилка переміщення</translation>
    </message>
    <message>
        <source>Session aborted by user or system</source>
        <translation>Сесія була перервана користувачем або системою</translation>
    </message>
    <message>
        <source>The specified configuration cannot be used.</source>
        <translation>Вказана конфігурація не може бути використана.</translation>
    </message>
    <message>
        <source>Unidentified Error</source>
        <translation>Неідентифікована помилка</translation>
    </message>
    <message>
        <source>QSystemReadWriteLock::QSystemReadWriteLock: unable to make key file for key: %1(%2)</source>
        <translation>QSystemReadWriteLock::QSystemReadWriteLock: неможливо створити ключовий файл для ключа: %1(%2)</translation>
    </message>
    <message>
        <source>QSystemReadWriteLock::QSystemReadWriteLock: ftok failed for key %1(%2)</source>
        <translation>QSystemReadWriteLock::QSystemReadWriteLock: збій ftok для ключа %1(%2)</translation>
    </message>
    <message>
        <source>QSystemReadWriteLock::QSystemReadWriteLock: Unable to access semaphore set for key %1(%2)</source>
        <translation>QSystemReadWriteLock::QSystemReadWriteLock: Неможливо отримати доступ до семафору, встановленого для ключа %1(%2)</translation>
    </message>
    <message>
        <source>QSystemReadWriteLock:QSystemReadWriteLock: Unable to access semaphore set for key %1(%2)</source>
        <translation>QSystemReadWriteLock::QSystemReadWriteLock: Неможливо отримати доступ до семафору, встановленого для ключа %1(%2)</translation>
    </message>
    <message>
        <source>QSystemReadWriteLock::QSystemReadWriteLock: Unable to reset semaphore set for key %1(%2)</source>
        <translation>QSystemReadWriteLock::QSystemReadWriteLock: Неможливо скинути семафор, встановлений для ключа %1(%2)</translation>
    </message>
    <message>
        <source>QSystemReadWriteLock::QSystemReadWriteLock: Unable to increment NumInstances semaphore for key%1(%2)</source>
        <translation>QSystemReadWriteLock::QSystemReadWriteLock: Неможливо інкрементувати семафор NumInstances для ключа %1(%2)</translation>
    </message>
    <message>
        <source>QSystemReadWriteLock::lockForRead: Unable to lock for read for key %1(Lock had not been correctly initialized)</source>
        <translation>QSystemReadWriteLock::lockForRead: Неможливо замкнути для читання ключ %1 (Блокування не було коректно ініціалізоване)</translation>
    </message>
    <message>
        <source>QSystemReadWriteLock::lockForRead: Unable to lock for read for key %1(%2)</source>
        <translation>QSystemReadWriteLock::lockForRead: Неможливо замкнути для читання ключ %1(%2)</translation>
    </message>
    <message>
        <source>QSystemReadWriteLock::lockForWrite: Unable to lock for write for key %1(Lock had not been correctly initialized)</source>
        <translation>QSystemReadWriteLock::lockForWrite: Неможливо замкнути для запису ключ %1 (Блокування не було коректно ініціалізоване)</translation>
    </message>
    <message>
        <source>QSystemReadWriteLock::lockForWrite: Could not increment TotalWriters semaphore for key %1(%2)</source>
        <translation>QSystemReadWriteLock:::lockForWrite: Не вдалось інкрементувати семафор TotalWriters для ключа %1(%2)</translation>
    </message>
    <message>
        <source>QSystemReadWriteLock::lockForWrite: Could not detect if all readers were finished for key %1(%2)</source>
        <translation>QSystemReadWriteLock::lockForWrite: Не вдалось визначити чи усі читачі були завершені для ключа %1(%2)</translation>
    </message>
    <message>
        <source>QSystemReadWriteLock::lockForWrite: Could not decrement ActiveWriterSem semaphore for key %1(%2)</source>
        <translation>QSystemReadWriteLock:::lockForWrite: Не вдалось декрементувати семафор ActiveWriterSem для ключа %1(%2)</translation>
    </message>
    <message>
        <source>QSystemReadWriteLock::unlock: Unable to unlock for key %1(Lock had not been correctly initialized)</source>
        <translation>QSystemReadWriteLock::unlock: Неможливо розблокувати ключ %1 (Блокування не було коректно ініціалізоване)</translation>
    </message>
    <message>
        <source>QSystemSemaphoreWriteLock::unlock: Unable to check and update writer semaphores for key %1(%2)</source>
        <translation>QSystemSemaphoreWriteLock::unlock: Неможливо перевірити та оновити семафори записувача для ключа %1(%2)</translation>
    </message>
    <message>
        <source>QSystemReadWriteLock::unlock: Unable to decrement ActiveReaders semaphore for key %1(%2)</source>
        <translation>QSystemReadWriteLock::unlock: Неможливо декрементувати семафор ActiveReaders для ключа %1(%2)</translation>
    </message>
    <message>
        <source>QSystemReadWriteLockPrivate::QSystemReadWriteLockPrivate: Unable to create/attach to shared memory</source>
        <translation>QSystemReadWriteLockPrivate::QSystemReadWriteLockPrivate: Неможливо створити/приєднатись до спільної пам&apos;яті</translation>
    </message>
    <message>
        <source>QSystemReadWriteLockPrivate::QSystemReadWriteLockPrivate: Unable to initialize shared memory</source>
        <translation>QSystemReadWriteLockPrivate::QSystemReadWriteLockPrivate: Неможливо ініціалізувати спільну пам&apos;ять</translation>
    </message>
    <message>
        <source>QSystemReadWriteLock::lockForRead(): cannot peform operation, lock initialization had not been successful</source>
        <translation>QSystemReadWriteLock::lockForRead(): неможливо виконати операцію, невдала ініціалізація блокування</translation>
    </message>
    <message>
        <source>QSystemReadWriteLock::lockForRead(): cannot perform operation, locking of shared memory was unsuccessful</source>
        <translation>QSystemReadWriteLock::lockForRead(): неможливо виконати операцію, невдале блокування спільної пам&apos;яті</translation>
    </message>
    <message>
        <source>QSystemReadWriteLock::lockForWrite(): cannot peform operation, lock initialization had not been successful</source>
        <translation>QSystemReadWriteLock::lockForWrite(): неможливо виконати операцію, невдала ініціалізація блокування</translation>
    </message>
    <message>
        <source>QSystemReadWriteLock::lockForwrite(): cannot perform operation, locking of shared memory was unsuccessful</source>
        <translation>QSystemReadWriteLock::lockForWrite(): неможливо виконати операцію, невдале блокування спільної пам&apos;яті</translation>
    </message>
    <message>
        <source>QSystemReadWriteLock::unlock(): cannot peform operation, lock initialization had not been successful</source>
        <translation>QSystemReadWriteLock::unlock(): неможливо виконати операцію, невдала ініціалізація блокування</translation>
    </message>
</context>
<context>
    <name>QXAPlaySession</name>
    <message>
        <source>Service has not been started</source>
        <translation>Сервіс не було запущено</translation>
    </message>
    <message>
        <source>Unable to load media</source>
        <translation>Неможливо завантажити медіа</translation>
    </message>
    <message>
        <source>Resources Unavailable</source>
        <translation>Ресурси недоступні</translation>
    </message>
</context>
<context>
    <name>QXARecordSession</name>
    <message>
        <source>Service has not been started</source>
        <translation>Сервіс не було запущено</translation>
    </message>
    <message>
        <source>Unable to start Service</source>
        <translation>Неможливо запустити сервіс</translation>
    </message>
    <message>
        <source>Generic error</source>
        <translation>Загальна помилка</translation>
    </message>
    <message>
        <source>Settings cannot be changed once recording started</source>
        <translation>Налаштування не можуть бути змінені після початку запису</translation>
    </message>
    <message>
        <source>Unable to pause</source>
        <translation>Неможливо призупинити</translation>
    </message>
    <message>
        <source>Unable to stop</source>
        <translation>Неможливо зупинити</translation>
    </message>
    <message>
        <source>Resources Unavailable</source>
        <translation>Ресурси недоступні</translation>
    </message>
    <message>
        <source>Invalid endpoint</source>
        <translation>Неправильна кінцева точка</translation>
    </message>
    <message>
        <source>Invalid container</source>
        <translation>Неправильний контейнер</translation>
    </message>
    <message>
        <source>Invalid codec</source>
        <translation>Неправильний кодек</translation>
    </message>
    <message>
        <source>Invalid encoding mode setting</source>
        <translation>Неправильні налаштування режиму кодування</translation>
    </message>
    <message>
        <source>Internal error</source>
        <translation>Внутрішня помилка</translation>
    </message>
    <message>
        <source>Invalid sample rate</source>
        <translation>Неправильний розмір семплу</translation>
</context>
<context>
    <name>S60CameraImageCaptureControl</name>
    <message>
        <source>DriveMode not supported.</source>
        <translation>Режим драйвера не підтримується.</translation>
    </message>
    <message>
        <source>Incorrect CaptureMode.</source>
        <translation>Неправильний режим захоплення.</translation>
    </message>
</context>
<context>
    <name>S60MediaPlayerControl</name>
    <message>
        <source>Media couldn&apos;t be resolved</source>
        <translation>Не вдалось розв&apos;язати медіа</translation>
    </message>
</context>
<context>
    <name>S60MediaRecorderControl</name>
    <message>
        <source>Video capture mode is not selected.</source>
        <translation>Не обрано режим захоплення відео.</translation>
    </message>
</context>
<context>
    <name>QDeclarativeGalleryItem</name>
    <message>
        <source>An error was encountered connecting to the document gallery</source>
        <translation>Під час підключення до галереї документів сталась помилка</translation>
    </message>
    <message>
        <source>The value of item is not a valid item ID</source>
        <translation>Значення елемента не є правильним ідентифікатором елемента</translation>
    </message>
</context>
<context>
    <name>QDeclarativeGalleryQueryModel</name>
    <message>
        <source>An error was encountered connecting to the document gallery</source>
        <translation>Під час підключення до галереї документів сталась помилка</translation>
    </message>
    <message>
        <source>DocumentGallery.InvalidType is not a supported item type</source>
        <translation>DocumentGallery.InvalidType не є підтримуваним типом елемента</translation>
    </message>
    <message>
        <source>DocumentGallery.%1 is not a supported item type</source>
        <translation>DocumentGallery.%1 не є підтримуваним типом елемента</translation>
    </message>
    <message>
        <source>The value of rootItem is not a valid item ID</source>
        <translation>Значення rootItem не є правильним ідентифікатором елемента</translation>
    </message>
    <message>
        <source>The value of filter is unsupported</source>
        <translation>Значення фільтра не підтримується</translation>
    </message>
</context>
<context>
    <name>QDeclarativeGalleryType</name>
    <message>
        <source>An error was encountered connecting to the document gallery</source>
        <translation>Під час підключення до галереї документів сталась помилка</translation>
    </message>
    <message>
        <source>DocumentGallery.%1 is not a supported item type</source>
        <translation>DocumentGallery.%1 не є підтримуваним типом елемента</translation>
    </message>
</context>
<context>
    <name>QDeclarativeLandmarkAbstractModel</name>
    <message>
        <source>LandmarkAbstractModel is an abstract class</source>
        <translation>LandmarkAbstractModel - абстрактний клас</translation>
    </message>
</context>
<context>
    <name>S60CameraViewfinderEngine</name>
    <message>
        <source>General viewfinder error.</source>
        <translation>Загальна помилка видошукача.</translation>
    </message>
    <message>
        <source>Viewfinder output not supported.</source>
        <translation>Виведення видошукача не підтримується.</translation>
    </message>
    <message>
        <source>Requested viewfinder size is not supported.</source>
        <translation>Розмір видошукача, що запитується, не підтримується.</translation>
    </message>
    <message>
        <source>Starting viewfinder failed.</source>
        <translation>Збій запуску видошукача.</translation>
    </message>
    <message>
        <source>Requesting window for viewfinder failed.</source>
        <translation>Збій запиту вікна для видошукача.</translation>
    </message>
    <message>
        <source>Viewfinder format not supported.</source>
        <translation>Формат видошукача не підтримується.</translation>
    </message>
    <message>
        <source>Camera rotation failed.</source>
        <translation>Збій повороту камери.</translation>
    </message>
    <message>
        <source>Presenting viewfinder frame failed.</source>
        <translation>Збій представлення кадру видошукача.</translation>
    </message>
    <message>
        <source>Invalid viewfinder frame was received.</source>
        <translation>Отримано неправильний кадр видошукача.</translation>
    </message>
    <message>
        <source>Failed to convert viewfinder frame to presentable image.</source>
        <translation>Збій конвертування кадру видошукача в зображення.</translation>
    </message>
</context>
<context>
    <name>CameraBinSession</name>
    <message>
        <source>Camera error</source>
        <translation>Помилка камери</translation>
    </message>
</context>
<context>
    <name>QGstreamerServicePlugin</name>
    <message>
        <source>Main Camera</source>
        <translation>Головна камера</translation>
    </message>
    <message>
        <source>Front Camera</source>
        <translation>Передня камера</translation>
    </message>
</context>
</TS>
